After executing test cases we can view the results in greater detail via a small
set of files:

  - **test_results.html**:
    A user-browsable HTML view of test case results.
  - **test_results.log**:
    A log file with logging traces collected from every individual test case.
  - **test_results.subunit**:
    The original subunit binary file generated by test runner.
  - **test_results.xml**:
    An XML Junit file to be used, for example, to show test cases result by
    Jenkins CI server.

The names of the above files can be changed from the default value (*test_results*)
to a custom one by setting the *TOX_REPORT_NAME* environment variable.

.. sidebar:: Legend

    *{toxinidir}* stands for the Tobiko source files directory.

    *{envname}* is the name of the Tox enviroment to be executed (IE scenario,
    faults, etc.)

The above files are saved into a folder that can be specified with
*TOX_REPORT_DIR* environment variable.

By default the full path of the report directory is made from the below::

    {toxinidir}/report/{envname}
